=======
anthill
=======


.. image:: https://img.shields.io/pypi/v/anthill.svg
        :target: https://pypi.python.org/pypi/anthill

.. image:: https://img.shields.io/travis/ayushpallav/anthill.svg
        :target: https://travis-ci.com/ayushpallav/anthill




An intelligent general purpose automation system.


* Free software: MIT license
* Documentation: https://anthill.readthedocs.io.


Features
--------

*

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
